package com.ozs.pm.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;

import com.ozs.base.domain.vo.BaseExpertVo;
import com.ozs.pm.doman.PmDemand;
import com.ozs.pm.doman.vo.requestVo.PmDemandReqVo;
import com.ozs.pm.doman.vo.responseVo.StatisticalChartsResVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;


/**
 * 采购需求Mapper接口
 *
 * @author ruoyi
 * @date 2023-01-16
 */
public interface PmDemandMapper extends BaseMapper<PmDemand> {

    /**
     * 通过需求ID列表，查询采购执行列表 sunhh
     *
     * @param demandIdList
     * @return
     */
    List<PmDemand> selectByDemandIdList(@Param("demandIdList") List<Integer> demandIdList);

    /**
     * 专家库--查询抽取专家列表 非必传条件：专家名称，开始结束时间 sunhh
     *
     * @param baseExpertVo
     * @return
     */
    List<PmDemand> selectExtractionExpert(BaseExpertVo baseExpertVo);

    /**
     * 统计分析-采购项目信息统计-查询项目总数量
     *
     * @param pmDemandReqVo
     * @return
     */
    Map<String, Integer> purchaseProjectStatistical(PmDemandReqVo pmDemandReqVo);

    /**
     * 统计分析-采购项目信息统计-查询已完成项目数量，预算金额数量
     *
     * @param pmDemandReqVo
     * @return
     */
    Map<String, Integer> purchaseProjectStatisticalYWC(PmDemandReqVo pmDemandReqVo);

    /**
     * 统计分析-采购项目信息统计-查询新创建项目数量，预算金额数量
     *
     * @param pmDemandReqVo
     * @return
     */
    Map<String, Integer> purchaseProjectStatisticalXCJ(PmDemandReqVo pmDemandReqVo);

    /**
     * 统计分析-采购项目信息统计-查询去年完成项目数量，预算金额数量
     *
     * @param pmDemandReqVo
     * @return
     */
    Map<String, Integer> purchaseProjectStatisticalQNWC(PmDemandReqVo pmDemandReqVo);

    /**
     * 按照项目属性统计所有的项目
     *
     * @return
     */
    List<StatisticalChartsResVo> countByProjectAttr();

    /**
     * 按照概算金额统计所有的项目
     *
     * @return
     */
    StatisticalChartsResVo countByEvaluationLt(Integer evaluation);

    StatisticalChartsResVo countByEvaluationBet(@Param("evaluation") Integer evaluation, @Param("evaluationEnd") Integer evaluationEnd);

    StatisticalChartsResVo countByEvaluationGt(Integer evaluation);
}
